package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````&"````````!``````````$"A````
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````,2/````````Q(\`````````
M``$```````$````&````>)L```````!XFP$``````'B;`0````````4`````
M``!8%0```````````0```````@````8```"(FP```````(B;`0``````B)L!
M``````#@`0```````.`!````````"`````````!0Y71D!````%2*````````
M5(H```````!4B@```````-P`````````W``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```!XFP```````'B;`0``````>)L!``````"(!```````
M`(@$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!/````!`````@````A````!<`$@"@`$`&`AD"`@B$`!`D`!(F(
M@!A!N@0""$\```!0````5````%D```!:````8````&$```!B`````````&0`
M`````````````&4```!F````:````````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV_B1\8!
M6.^7>;OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[7^IG)O@IP(*O]I7&Z/@^TD`
M``````````````````````````````````````````,`!P`(&@``````````
M``````````````,`$@``H`$`````````````````#````!(`````````````
M````````````TP$``!(`````````````````````````%````!$`````````
M````````````````^0$``!$`````````````````````````=0$``!(`````
M````````````````````&P```!(`````````````````````````L@$``!(`
M````````````````````````(P```!(`````````````````````````*@``
M`!(`````````````````````````!@(``!(`````````````````````````
MO@$``!(`````````````````````````,P```"``````````````````````
M````4`,``"$`````````````````````````2P```!(`````````````````
M````````40```!(`````````````````````````6````!(`````````````
M````````````%@,``!(`````````````````````````!P,``!(`````````
M````````````````BP(``!(`````````````````````````7P```!(`````
M````````````````````+`(``!(`````````````````````````9@```!(`
M````````````````````````P`(``!(`````````````````````````;0``
M`!(`````````````````````````=0```!(`````````````````````````
MJ0(``!(`````````````````````````?0```!(`````````````````````
M````@P```!(`````````````````````````C````"``````````````````
M``````````,``!(`````````````````````````J````!(`````````````
M````````````K0```!(`````````````````````````%P(``!$`````````
M````````````````QP(``!(`````````````````````````60(``!(`````
M````````````````````)@,``!(`````````````````````````2P(``!(`
M````````````````````````=`,``!(`````````````````````````T@(`
M`!$`````````````````````````3P,``!$`````````````````````````
M?0(``!(`````````````````````````/`,``!(`````````````````````
M````40,``!$`````````````````````````M````!(`````````````````
M````````-`,``!(`````````````````````````O0```!$`````````````
M````````````@P$``!(`````````````````````````SP```"(`````````
M````````````````W@```"``````````````````````````]````!(`````
M````````````````````^`(``!(`````````````````````````:0(``!(`
M````````````````````````^0```!(`````````````````````````_P``
M`"``````````````````````````M`(``!(`````````````````````````
M&0$``!(`````````````````````````HP$``!(`````````````````````
M````'@$``!(`````````````````````````F0(``!(`````````````````
M````````D@$``!(`````````````````````````)`$``!(`````````````
M````````````-0$``!(`````````````````````````)P(``!(`````````
M````````````````?@```!(`````````````````````````.`(``!(`````
M````````````````````<@(``!(`````````````````````````+0,``!(`
M````````````````````````.P$``!(`````````````````````````'@,`
M`!(`````````````````````````3P$``!(`````````````````````````
M(@(``!(`````````````````````````X0$``!(`````````````````````
M````5@$``!(`````````````````````````70$``!(`````````````````
M````````3@,``"$`````````````````````````;@$``!(`````````````
M````````````5@0``!``$P#0L`$`````````````````20,``!(`"0`@'@``
M`````/@!````````\P$``!(`"@`H2P````````0`````````M@,``!(`"0`@
M/P```````%0(````````9@0``!(`"0#$2@```````&0`````````DP,``!(`
M"0!,.0````````0`````````Q0,``!(`!P`(&@````````0`````````V0,`
M`!(`"0!T1P```````%`#````````&@0``!``$P!XH`$`````````````````
M2`0``!(`"0!0.0```````-`!````````!@0``!``$P!XH`$`````````````
M````I`,``!(`"0!L/@```````+0`````````PP,``!(`"0"0-P```````#@`
M````````RP,``!(`"0#L/0```````%@`````````^0,``!(`"0`@.P``````
M`"0`````````$@0``!``$P#0L`$`````````````````800``!``$P#0L`$`
M````````````````60,``!(`"0`T(````````#``````````*`0``!(`"0!$
M.P`````````!````````[P,``!$`$@!PH`$```````@`````````000``!``
M$@!XH`$`````````````````"P0``!(`"0`8(```````````````````8@,`
M`!(`"0!$/@```````"@`````````?0,``!(`"0`<.````````#`!````````
M500``!``$P#0L`$`````````````````-`0``!(`"0!$/````````*@!````
M`````&QI8G!E<FPN<V\`;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`
M<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED
M`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!L<W1A=`!C
M;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S
M='(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`
M7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E
M<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD
M:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC<'D`<W1R;&5N`%]?<W1A8VM?
M8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V
M7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!03%]M96UO<GE?=W)A<`!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ`&9P
M<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT9@!S
M=')C:'(`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV
M:7)O;@!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?
M8G-S7W-T87)T`%]?96YD7U\`7U]B<W-?<W1A<G1?7P!P87)?9&ER;F%M90!P
M87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!?7V)S<U]E;F1?7P!?
M96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%
M`'B;`0```````P0````````P(0```````(";`0```````P0```````#((```
M`````'B?`0```````P0````````@'@```````)"?`0```````P0````````H
M2P```````*B?`0```````P0````````(&@````````"@`0```````P0`````
M````H`$``````!"@`0```````P0````````:3@```````!B@`0```````P0`
M``````!E2P```````"B@`0```````P0```````!&3````````#"@`0``````
M`P0````````_3````````#B@`0```````P0````````.3@```````$"@`0``
M`````P0```````!<3````````$B@`0```````P0````````63@```````%B@
M`0```````P0`````````3@```````&"@`0```````P0````````%3@``````
M`'"@`0```````P0````````?3@```````("?`0```````00```4`````````
M`````(B?`0```````00```8``````````````)B?`0```````00```X`````
M`````````*"?`0```````00``!\``````````````+"?`0```````00``",`
M`````````````+B?`0```````00``"D``````````````,"?`0```````00`
M`"T``````````````,B?`0```````00``#```````````````-"?`0``````
M`00``#(``````````````-B?`0```````00``#,``````````````."?`0``
M`````00``#@``````````````.B?`0```````00``#T``````````````/"?
M`0```````00``#X``````````````/B?`0```````00``$,`````````````
M`("=`0```````@0```,``````````````(B=`0```````@0```0`````````
M`````)"=`0```````@0```<``````````````)B=`0```````@0```@`````
M`````````*"=`0```````@0```D``````````````*B=`0```````@0```H`
M`````````````+"=`0```````@0```L``````````````+B=`0```````@0`
M``P``````````````,"=`0```````@0```T``````````````,B=`0``````
M`@0```X``````````````-"=`0```````@0``!```````````````-B=`0``
M`````@0``!$``````````````."=`0```````@0``!(``````````````.B=
M`0```````@0``!,``````````````/"=`0```````@0``!0`````````````
M`/B=`0```````@0``!4```````````````">`0```````@0``!8`````````
M``````B>`0```````@0``!<``````````````!">`0```````@0``!@`````
M`````````!B>`0```````@0``!D``````````````"">`0```````@0``!H`
M`````````````"B>`0```````@0``!L``````````````#">`0```````@0`
M`!P``````````````#B>`0```````@0``!T``````````````$">`0``````
M`@0``!X``````````````$B>`0```````@0``"```````````````%">`0``
M`````@0``"$``````````````%B>`0```````@0``"(``````````````&">
M`0```````@0``"0``````````````&B>`0```````@0``"4`````````````
M`'">`0```````@0``"8``````````````'B>`0```````@0``"<`````````
M`````(">`0```````@0``"@``````````````(B>`0```````@0``"L`````
M`````````)">`0```````@0``"P``````````````)B>`0```````@0``"X`
M`````````````*">`0```````@0``"\``````````````*B>`0```````@0`
M`#$``````````````+">`0```````@0``#(``````````````+B>`0``````
M`@0``#,``````````````,">`0```````@0``#0``````````````,B>`0``
M`````@0``#4``````````````-">`0```````@0``#8``````````````-B>
M`0```````@0``#<``````````````.">`0```````@0``#D`````````````
M`.B>`0```````@0``#H``````````````/">`0```````@0``#L`````````
M`````/B>`0```````@0``#P```````````````"?`0```````@0``#\`````
M``````````B?`0```````@0``$```````````````!"?`0```````@0``$$`
M`````````````!B?`0```````@0``$(``````````````""?`0```````@0`
M`$0``````````````"B?`0```````@0``$4``````````````#"?`0``````
M`@0``$8``````````````#B?`0```````@0``$<``````````````$"?`0``
M`````@0``$@``````````````$B?`0```````@0``$D``````````````%"?
M`0```````@0``$H``````````````%B?`0```````@0``$L`````````````
M`&"?`0```````@0``$P``````````````&B?`0```````@0``$X`````````
M`````/U[OZG]`P"1_7O!J,`#7]8``````````/![OZG0``"0$;Y&^1#B-9$@
M`A_6'R`#U1\@`]4?(`/5T```D!'"1OD0`C:1(`(?UM```)`1QD;Y$"(VD2`"
M'];0``"0$<I&^1!"-I$@`A_6T```D!'.1OD08C:1(`(?UM```)`1TD;Y$((V
MD2`"'];0``"0$=9&^1"B-I$@`A_6T```D!':1OD0PC:1(`(?UM```)`1WD;Y
M$.(VD2`"'];0``"0$>)&^1`"-Y$@`A_6T```D!'F1OD0(C>1(`(?UM```)`1
MZD;Y$$(WD2`"'];0``"0$>Y&^1!B-Y$@`A_6T```D!'R1OD0@C>1(`(?UM``
M`)`1]D;Y$*(WD2`"'];0``"0$?I&^1#"-Y$@`A_6T```D!'^1OD0XC>1(`(?
MUM```)`1`D?Y$`(XD2`"'];0``"0$09'^1`B.)$@`A_6T```D!$*1_D00CB1
M(`(?UM```)`1#D?Y$&(XD2`"'];0``"0$1)'^1"".)$@`A_6T```D!$61_D0
MHCB1(`(?UM```)`1&D?Y$,(XD2`"'];0``"0$1Y'^1#B.)$@`A_6T```D!$B
M1_D0`CF1(`(?UM```)`1)D?Y$"(YD2`"'];0``"0$2I'^1!".9$@`A_6T```
MD!$N1_D08CF1(`(?UM```)`1,D?Y$((YD2`"'];0``"0$39'^1"B.9$@`A_6
MT```D!$Z1_D0PCF1(`(?UM```)`1/D?Y$.(YD2`"'];0``"0$4)'^1`".I$@
M`A_6T```D!%&1_D0(CJ1(`(?UM```)`12D?Y$$(ZD2`"'];0``"0$4Y'^1!B
M.I$@`A_6T```D!%21_D0@CJ1(`(?UM```)`15D?Y$*(ZD2`"'];0``"0$5I'
M^1#".I$@`A_6T```D!%>1_D0XCJ1(`(?UM```)`18D?Y$`([D2`"'];0``"0
M$69'^1`B.Y$@`A_6T```D!%J1_D00CN1(`(?UM```)`1;D?Y$&([D2`"'];0
M``"0$7)'^1"".Y$@`A_6T```D!%V1_D0HCN1(`(?UM```)`1>D?Y$,([D2`"
M'];0``"0$7Y'^1#B.Y$@`A_6T```D!&"1_D0`CR1(`(?UM```)`1AD?Y$"(\
MD2`"'];0``"0$8I'^1!"/)$@`A_6T```D!&.1_D08CR1(`(?UM```)`1DD?Y
M$((\D2`"'];0``"0$99'^1"B/)$@`A_6T```D!&:1_D0PCR1(`(?UM```)`1
MGD?Y$.(\D2`"'];0``"0$:)'^1`"/9$@`A_6T```D!&F1_D0(CV1(`(?UM``
M`)`1JD?Y$$(]D2`"'];0``"0$:Y'^1!B/9$@`A_6T```D!&R1_D0@CV1(`(?
MUM```)`1MD?Y$*(]D2`"'];]>[NI_0,`D?-3`:G3``"PU```D/43`/GBAP.I
MXN,`D>$#`9'@3P"YX#,!D9'__Y?"``"0P```D$+\1_D`^$?YX0,"JB___Y?`
M``"0`,1'^0``0#F``0`U8O__EV+"`I%`#`#Y8```M2``@%*-__^7I/__EX#:
M1_D``$"YP?__EQ^$)#F4VD?Y@`)`N;W__Y<!Z%,Y(0`?,@'H$SF``D"YN/__
MEP'H4SDA```R`>@3.>!/0+D!`/R2`!0`$0!\0),?``'KR0``5,$``)````#P
M`*PND2'<1_GR_O^7`/!]TX#__Y?E(T#Y8L("D>0`@)*A`$#Y`0``^0$``/`A
MZ#>1`00`^<$``+!`!`#Y(3A`^0$(`/D!``#P(?0WD0$,`/F!`(!2000`N0$`
M@-+B3T"Y(00`D5\``6ML!0!401``$77"`I'C`P"J0@P`$8',(8L$`(#2'V@A
M^`$``-"@#D#Y(2`?D0?__Y?T`P`J@```-:`.0/E3__^7]`,`*G7"`I&@#D#Y
M*___EP```/``Y"^1U`0`E&`!`+6@"D#YH```M0```/``N"Z1S@0`E*`*`/E@
MP@*1``A`^4```+2Z"@"4<\("D6`.0/EZ__^7G?[_E^`#%"KS4T&I]1-`^?U[
MQ:C``U_6(Q``$:9X8?B#S".+!F@C^,___Q<=`(#2'@"`TN`#`)&A``#P(2`N
MD1_L?)(!```4_7N_J:0``/"C``#P_0,`D0&$0/@%`(#2A,A'^>(#`*J@``#P
M8]1'^0"\1_D`__^7P```D`#@`9'!``"0(>`!D3\``.N@``!4H0``\"'01_E!
M``"T(``?UL`#7];```"0`.`!D<$``)`AX`&1(0``RT(`@-(A_$.3(0S"FJ$`
M`+2B``#P0O!'^4(``+1``!_6P`-?UL```)`!X$$YX0(`-?U[OJG]`P"1\PL`
M^?,#`*J@``#P`.A'^8```+3```"0``!`^>K^_Y?:__^7H```\`#,1_F```"T
M(```T`#`+)%O_O^7(`"`4F#B`3GS"T#Y_7O"J,`#7];``U_6H```\`#L1_D@
M`0"T_7N_J<$``)`@``#0_0,`D2$``I$`P"R1U_[_E_U[P:C-__\7_X,*T:4`
M`/#C8P"1!N``D0C@`9'G`P.J_7L`J?T#`)&AY$?Y(@!`^>)/`?D"`(#2P0!`
MN>=``)'$A$#X(0C`6N$`'_C?``CK@?Q@TR(<"%,AW'C3(1QPDD$``:J"_&C3
M0AQXDD3@1*HA``2JX8`?^`'^_U0$"(!28B!`^80$`'%A-$#Y8R``D6:`7_@B
M``+*801`^2$`!LI!``'*(OQ?TT$$`:HA?$"283P`^6'^_U0'&$"I*S./T@@D
M0:E+4*OR"A!`^>'\6]/L_$+3(10'JHQY!ZHB`0C*D'U`DD(`!HI"``G*04`A
MB^*30:E"``N+A``+BR$``HO"_$+30G@&JB$`"@M.?$"230`,RL,!",JM`0&*
M8P`'BJT!#LIC``C*K0$(BV,`"8MD``2+(_Q;TV,4`:IC``0+)/Q"TX1X`:KB
MAT*IC`$$RHP!`XJ/?$"2C`$0RHP!#HM"``N+(0`+BZT!`HMB_%O30A0#JHP!
M`8M"``T+0?Q;TR$4`JHA``P+;/Q"TX-Y`ZI,_$+3C@`#RG%\0)+.`0**@GD"
MJFT``LK.`0_*Y(]#J<X!$(NM`0&*+/Q"TZT!$<I0?$"2K0$/BX0`"XMC``N+
MS@$$BR3\6].$%`&J@7D!JH0`#@NM`0.+3``!RB]\0)*#_%O3C`$$BN(G0/EC
M%`2J8P`-"XP!$,I"``N+C`$1BXP!`HMB_%O30A0#JD(`#`N,_$+3A'D$JFS\
M0M,N``3*D7Q`DLX!`XJ#>0.JC0`#RLX!#\KA$T6IS@$0BZT!`HI,_$+3K0$1
MRG!\0)*M`0^+(0`+BX0`"XO.`0&+0?Q;TR$4`JJ">0*J(0`."ZT!!(ML``+*
M3WQ`DB3\6].,`0&*XS-`^804`:J$``T+C`$0RF,`"XN,`1&+C`$#BX/\6]-C
M%`2J8P`,"RS\0M.!>0&JC/Q"TTX``<HQ?$"2S@$$BH1Y!*HM``3*S@$/RN*'
M1JG.`1"+K0$#BFS\0M.M`1'*D'Q`DJT!#XM"``N+(0`+B\X!`HMB_%O30A0#
MJH-Y`ZI"``X+K0$!BXP``\IO?$"20?Q;TXP!`HKD/T#Y(10"JB$`#0N,`1#*
MA``+BXP!$8N,`02+)/Q;TX04`:J$``P+3/Q"TX)Y`JIN``+*47Q`DN-#0/G.
M`0&*S@$/RF,`"XO.`1"+S@$#BX/\6]-C%`2J;@`."R/\0M-A>`&J30`!RC!\
M0)+B1T#YK0$$BJT!$<K#_4+30@`+BZT!#XNM`0*+POU;TT(4#JIC>`ZJ30`-
M"X+\0M-$>`2J+``$RH]\0)+A2T#YC`$.BHP!$,J$``/*(0`+BXP!$8N,`0&+
MH?U;TR$4#:J$``V*+``,"X0`#\KA3T#YA``0BZ+]0M-N?$"2(0`+BT)X#:J$
M``&+@?U;TR$4#*IC``+*)``$"V,`#(KA4T#Y8P`.RF,`#XM-?$"2(0`+BV,`
M`8N!_%O3(10$JB,``PN!_4+3(7@,JD(``<HO?$"2[%=`^4(`!(I"``W*C`$+
MBT(`#HM"``R+;/Q;TXP5`ZI"0"R+C/Q"TX1Y!*I.?$"2(0`$RNQ;0/DA``.*
M(0`/RHL!"XLA``V+(0`+B\O]6]-K%0ZJ(4`KBVO\0M-C>0.J,'Q`DHP``\HK
M=)W2C`$"2BO;K?+B7T#YC`$/BPW^6]-"``N+K140JHP!`HO"_4+30G@.JHQ!
M+8MM``+*D7U`DJ$!`4HD0"2++?Y;T^%C0/FM%1&J(0`+BX0``8L!_D+3(7@0
MJH1`+8M-``'*CWQ`DJP!#$J#02.+[?U;T^QG0/FM%0^JC`$+BV,`#(LL_D+3
MC'D1JF-`+8LM``S*;GQ`DJ0!!$J"0"*+S?U;T^1K0/FM%0ZJA``+BT(`!(OD
M_4+3A'@/JD)`+8N-`03*4'Q`DJ,!`TIA0"&+#?Y;T^-O0/FM%1"J8P`+BR$`
M`XO#_4+38W@.JB%`+8N-``/*+WQ`DJ(!`DI,0"R+[?U;T^)S0/FM%0^J0@`+
MBXP!`HL"_D+30G@0JHQ!+8MM``+*CGU`DJ$!`4HD0"2+S?U;T^%W0/FM%0ZJ
M(0`+BX0``8OA_4+3(7@/JH1`+8M-``'*D'Q`DJP!#$J#02.+#?Y;T^Q[0/FM
M%1"JC`$+BV,`#(O,_4+3C'D.JF-`+8LM``S*;WQ`DJ0!!$J"0"*+[?U;T^1_
M0/FM%0^JA``+BT(`!(L$_D+3A'@0JD)`+8N-`03*3GQ`DJ,!`TIA0"&+S?U;
MT^.#0/FM%0ZJ8P`+BR$``XOC_4+38W@/JB%`+8N-``/*,'Q`DJ(!`DI,0"R+
M#?Y;T^*'0/FM%1"J0@`+BXP!`HO"_4+30G@.JHQ!+8MM``+*CWU`DJ$!`4HD
M0"2+[?U;T^&+0/FM%0^J(0`+BX0``8L!_D+3(7@0JH1`+8M-``'*CGQ`DJP!
M#$J#02.+S?U;T^R/0/FM%0ZJC`$+BV,`#(OL_4+3C'D/JF-`+8LM``S*<'Q`
MDJ0!!$J"0"*+#?Y;T^230/FM%1"JA``+BT(`!(O$_4+3A'@.JD)`+8N.`03*
M37Q`DL,!`TIA0"&+KOU;T^.70/G.%0VJ8P`+BR$``XL#_D+38W@0JB%`+HN.
M``/*+WQ`DL(!`DI,0"R+[OU;T^*;0/G.%0^J0@`+BXP!`HN,02Z+KOU"T\UY
M#:J"?4"2;@`-RL$!`4I._%O3)$`DB\X5`JKAGT#Y(0`+BX0``8OA_4+3(7@/
MJH1`+HNO`0'*CGQ`DNP!#$J#02.+S_U;T^RC0/GO%0ZJC`$+BV,`#(M,_$+3
MD'D"JLS]0M,B`!#*C'D.JD0`!$IO0"^+C4`MBP0"#,KC?4"2CP`/2N*35*GA
M02&+0@`+BXL`"XNM`0*+9/Q"TV+\6],K``N+0A0#JH-X`ZI"``T+;WQ`DHU]
M0)*,`0.JI`$/BHP!`HI!_%O3C`$$JN2O0/DA%`*J(0`+"XN;E])KX['RC$$P
MBX0`"XN,`02+)/Q;TX04`:J,``P+1/Q"TX)X`JHD_$+347Q`DFX``JK.`0&*
MXP$1BH%X`:K.`0.J,'Q`DLX!#8M-``&J(@(0BJT!#(J$_4+3K0$"JH1X#*KC
M"U:IK0$/BX]\0))C``N+0@`+B\X!`XN#_5O38Q0,JBP`!*IC``X+`0(/BHP!
M`XJM`0*+C`$!JF+\6]/ANT#Y0A0#JD(`#0N,`1&+(0`+BXP!`8M!_%O3(10"
MJB$`#`ML_$+3@WD#JDS\0M-Q?$"2C@`#JLX!`HKD`1&*@GD"JLX!!*IM``*J
MS@$0BU!\0)*M`0&*(P(0BBS\0M.M`0.JY(]7J:T!#XN$``N+8P`+B\X!!(LD
M_%O3A!0!JH%Y`:J$``X++WQ`DDP``:H"`@^*C`$$BJT!`XN,`0*J@_Q;T^+'
M0/EC%`2J8P`-"XP!$8M"``N+C`$"BV+\6]-"%`.J0@`,"XS\0M.$>02J;/Q"
MTY%\0)(N``2JS@$#BN$!$8J#>0.JS@$!JHT``ZK.`1"+<'Q`DJT!`HHD`A"*
M3/Q"TZT!!*KA$UFIK0$/BR$`"XN$``N+S@$!BT'\6],A%`*J@GD"JB$`#@M/
M?$"2;``"J@,"#XJ,`0&*K0$$BXP!`ZHD_%O3X]-`^804`:J$``T+C`$1BV,`
M"XN,`0.+@_Q;TV,4!*IC``P++/Q"TX%Y`:J,_$+3,7Q`DDX``:K.`02*X@$1
MBH1Y!*K.`0*J+0`$JLX!$(N0?$"2K0$#BB$"$(IL_$+3K0$!JN*'6JFM`0^+
M0@`+BR$`"XO.`0*+8OQ;TT(4`ZJ#>0.J0@`."V]\0)*,``.J!`(/BHP!`HJM
M`0&+C`$$JD'\6]/DWT#Y(10"JB$`#0N,`1&+A``+BXP!!(LD_%O3A!0!JH0`
M#`M,_$+3@GD"JE%\0))N``*JS@$!BN,!$8K.`0.JX^-`^<X!$(MC``N+S@$#
MBX/\6]-C%`2J;@`."R/\0M-A>`&J,'Q`DDT``:JM`02*(@(0BJT!`JK#_4+3
MXN=`^:T!#XMC>`ZJ0@`+BZT!`HO"_5O30A0.JDT`#0N"_$+31'@$JH]\0)(L
M``2JC`$.B@$"#XJ,`0&J;GQ`DN'K0/F,`1&+A``#JJ+]0M,A``N+A``-BHP!
M`8NA_5O3(10-JD)X#:HL``P+X0$.BH0``:I-?$"2X>]`^80`$(MC``*J(0`+
MBV,`#(J$``&+@?U;TR$4#*HD``0+P0$-BF,``:KA\T#Y8P`/BX_\6],A``N+
M[Q4$JF,``8N!_4+3(7@,JN,!`PLL?$"20@`!JJ\!#(I"``2*0@`/JD(`#HON
M]T#YS@$+BT(`#HMN_%O3SA4#JDY`+HN"_$+31'@$JM%]0)*0?$"2(0`$JH(!
M$(HA``.*(0`"JN+[0/DA``V++?Y;TTL`"XNM%1&J(0`+BV+\0M,M0"V+3W@#
MJJM]0)*"``_*X?]`^4(`#DK$.IC2;OU;TT1,N?)"``R+(0`$B\X5"ZI"``&+
M(_Y"TTY`+HMC>!&JS'U`DN$!`\KB`T'Y(0`-2HW]6],A`!"+K14,JD(`!(LA
M``*+8OU"TR%`+8M+>`NJ[0=!^6(`"\HP?$"20@`.2JT!!(M"0"^+0@`-BPW^
M6].M%1"JI>1'^4)`+8N-_4+33WQ`DJQY#*IM`0S*H0$!2NW]6],C0".+K14/
MJN$+0?DA``2+8P`!BP'^0M,A>!"J8T`MBXT!`<IN?$"2H@$"2DM`*XO-_5O3
MX@]!^:T5#JI"``2+:P$"B^+]0M-">`^J:T$MBRT``LIP?4"2HP$#2FQ`+(L-
M_EO3XQ-!^:T5$*IC``2+C`$#B\/]0M-C>`ZJC$$MBTT``\J/?4"2JP$+2F%!
M(8OM_5O3ZQ=!^:T5#ZIK`02+(0`+BPO^0M-K>1"J(4`MBVT`"\HN?$"2K`$,
M2H)!(HO-_5O3[!M!^:T5#JJ,`02+0@`,B^S]0M.,>0^J0D`MBVT!#,I1?$"2
MH0$!2B-`(XLM_EO3X1]!^:T5$:HA``2+8P`!B\']0M,A>`ZJ8T`MBXT!`<IP
M?$"2H@$"2DM`*XL-_EO3XB-!^:T5$*I"``2+:P$"BR+^0M-">!&J:T$MBRT`
M`LIO?4"2HP$#2FQ`+(OM_5O3XR=!^:T5#ZIC``2+C`$#BP/^0M-C>!"JC$$M
MBTX``\J-?4"2RP$+2F%!(8NN_5O3ZRM!^<X5#:IK`02+(0`+B^O]0M-K>0^J
M(4`NBVX`"\HQ?$"2S`$,2H)!(HOL+T'YC`$$BT(`#(LL_EO3C!41JD)`+(NL
M_4+3C7D-JE!\0))L`0W*@0$!2@[^6],C0".+SA40JN$S0?DA``2+8P`!BR'^
M0M,A>!&J;D`NBZP!`<K#?4"2@@$"2DM`*XMO_%O3XC=!^>\5`ZI"``2+:P$"
MBP+^0M-">!"J;T$OBRP``LKK?4"2C@$.2NP[0?G-02V+;OU;TXP!!(O.%0NJ
MK0$,BVS\0M.#>0.JKD$NBTP``\K-?4"2CP$/2NP_0?GA02&+;_U"T^MY"ZJ,
M`02+;P`+RB$`#(NL_5O3[@$.2HP5#:K"02*+[D-!^2Q`+(N!?4"2K_U"T\X!
M!(OM>0VJ0@`.BV\!#<HN_%O3[`$,2LX5`:J#02.+[$=!^4Y`+HO"?4"2J@$*
M"XP!!(L*$`#Y;``,BT/\6]-C%`*J8P`,"RS\0M.!>0&J3/Q"TX)Y`JJL`0'*
MC@$.2BD`"0OL2T'YRT$KB\8``PM(``@+A`$$BP@D`:EK`02+9/Q;TX04`ZJ$
M``L+AP`'"P<8`*GA3T'YH`!`^2```,I```"T\_K_E_U[0*G_@PJ1P`-?UOU[
MO*G]`P"1\U,!J?5;`JGW8P.I``4`M*(``-!"X$?Y5P!`^9<$`+3B`P"J0P!`
M.7_T`'%D&$!Z80,`5$(``$OX`P&J]@,`JO4#%ZI3?$"3M`)`^=0!`+3B`Q.J
MX0,6JN`#%*HZ^O^7(`(`-8!J<S@?]`!QP0$`5+4"%\MS!@"1E`(3B[7^0Y,5
M`P"YX`,4JO-30:GU6T*I]V-#J?U[Q*C``U_60@0`D>'__Q>U(@"1Z/__%Q0`
M@-+U__\7_7N]J?T#`)'S"P#YLP``T'/F1_EA`D#YX1<`^0$`@-+ADP"1R/__
ME^(70/EA`D#Y00`!RD$``+2R^O^7\PM`^?U[PZC``U_6_7N\J?T#`)'U6P*I
M]0,`JJ```-#S4P&IM```T/,#`*H!Y$?Y]M,`D93B1_DB`$#YXA\`^0(`@-+A
M`Q:JX`,5JJ___Y?@``"U8.9'^>$?0/D``$#Y(```RD`!`+27^O^7@0)`^>`W
M@+D@#`"+`01`^0$``/DA_O^T`"``D?S__Q?S4T&I]5M"J?U[Q*C``U_6_7NZ
MJ?T#`)'S4P&IM```T/5;`JGV`P"J]0,!JH#F1_GW8P.I^6L$J0$`0/GA+P#Y
M`0"`TJ`"0#D?]`!Q00``5+4&`)'@`Q6J=/K_E^%3`9'W`P"JX`,6JH7__Y?S
M`P"J``(`M&WZ_Y<?`!?K8P8`5```@-*A:F`X86H@.``$`)&A__\U``"`4I3F
M1_GB+T#Y@0)`^4$``<JA"0"T8_K_E[,``-!@XD?Y&0!`^0``@-(B(P#1^`,`
M*@`$`)%!>&#XH?__M:$``/``"P`1(K!`N0!\?9,B`0`TX0,`JN`#&:IN^?^7
M8>)'^2```/F@`0"U``"`$N7__Q<B`(!2(K``N:;Y_Y?Z`P"J0/__M`)_?9/A
M`QFJI?G_EV#B1_D:``#Y<^)'^0!_0),`!`"180)`^3]X(/CX5P"YX`,6J@$`
M0#D_]`!Q)!A`>J$#`%2S``#0^%>`N0``%LOW"@"1<^)'^1CS?=/@PB"+>0)`
M^8OY_Y<@:SCXX/O_M.%7@+E@`D#Y`'AA^.$#`*K"%D`X(A0`.&(``#1?]`!Q
M80$`5*('@%("```Y``"`TJ)J8#@B:"`X``0`D:+__S6S__\7``0`D=___Q?@
M`P&J[___%_-30:GU6T*I]V-#J?EK1*G]>\:HP`-?UOU[LJG]`P"1\U,!J;0`
M`-"!YD?Y]5L"J?=C`ZGY:P2I(@!`^>)O`/D"`(#28`(`M`$`0#GU`P"J`0(`
M-!+Y_Y?W`P"JH`$`M!@``+`9``"P&)<MD3F3+9'Z8P&1X`,7JCWY_Y=@`0"U
MX`,7JF;Y_Y?@`Q6JP/G_EY3F1_GA;T#Y@`)`^2```,I@!0"T[OG_EQ-,`)'A
M`QBJX`,3JBKY_Y?@_?\TX0,9JN`#$ZHF^?^78/W_-.`#%:K?^?^7]@,`JN`#
M$ZK<^?^7```6"P`(`!$`?$"3./G_E^,#$ZKB`Q6J]@,`J@$``+`AG"V1POG_
ME^$#&JK@`Q:JK_G_EQ\$`#%``0!4X&M`N0`,%!(?$$!QP0``5.`#%JJZ__^7
MX`,6JJ'Y_Y?.__\7X`,6JA[Y_Y?[__\7\U-!J?5;0JGW8T.I^6M$J?U[SJC`
M`U_6_7NUJ?T#`)'S4P&ILP``T/0#`*IAYD?Y(@!`^>)7`/D"`(#2X:,`D2#Y
M_Y=``@`UX3M`N0(`E%(A#!02/Q!`<2000GK!``!400"`4N`#%*K.^/^7'P``
M<>`7GQISYD?YXE=`^6$"0/E!``'*@0``M*+Y_Y<``(!2^?__%_-30:G]>\NH
MP`-?UOU[OZF@``#0_0,`D0#81_D``$"Y?_G_EZ(``-`#``"P_7O!J&/@+)%"
M]$?Y`0``L"&T+9%O^?\7_7N^J?T#`)'S"P#YLP``T'/:1_E@`D"Y</G_E^O_
M_Y=@`D"Y;?G_E_,+0/D$``"P_7O"J(3D-Y$%`(!2XP,$J@(``+`!``"P0M`=
MD2$D+I&F^/\7$`J$TO]C,,O]>P"I_0,`D?5;`JFV``#0P.9'^?-3`:GTXP"1
M`0!`^>$G$/D!`(#2J?C_E^,#`"H$``"P`@``L(1X+I%"B"Z1(0""TN`#%*J-
M^/^7'P0`,2$!`%0#`(#2P>9'^>`#`ZKB)U#Y(0!`^4$``<HA!0"T6_G_EP%\
M0),_!$#Q20``5`!](-2`_O\W``B"TO-C((L"`(+2X0,3JN`#%*KL^/^7]0,`
MJH#]_S<`!``1`'Q`DZ?X_Y?C`P"JX/S_M+1^0),?`!/K@@``5```%(M_`@#K
M@_W_5'\`$^N)``!48`(4BW\``.OC_/]4(`""4K\"`&N,_/]4X`,#JN(#%*KA
M`Q.J)_G_E^,#`*H?:#0XT___%Q`*A-+]>T"I\U-!J?5;0JG_8S"+P`-?UK3_
M_Q<0'H+2_V,PR_U[`*G]`P"1\U,!J;0``-#S`P&J]5L"J?4#`*J`YD?Y]V,#
MJ?EK!*G[*P#Y`0!`^>%W"/D!`(#2````L`"X+I%:_O^7^@,`JN$%@%+@`Q6J
MGOC_EX`!`+0```"PX0,5J@#<+I&'_O^7E.9'^>`#%:KB=TCY@0)`^4$``<I!
M"0"T"OG_E^`#%:H$^?^7%@``L/L#`"K!$B^1X`,3JA@``+#F^/^7&0``L/,#
M`*H8ERV1.1LOD?>C`Y$3_?^T8`)`.1\``'%S$IB:6@$`M.$#$ZK@`QJJ-?C_
ME\```#7!$B^1``"`TM7X_Y?S`P"J\___%^`#$ZKI^/^78<(@BR'P7S@_O`!Q
M(`(`5&$'`!$@```+'_P_<2SZ_U3E`Q6JY`,9JN,#$ZH"``"P`0""TD*(,I'@
M`Q>J!?C_EP`$`!$?!$!QJ0``5`!](-0`!`!1?\H@..K__Q?AHP&1X`,7JJ_X
M_Y?@^_\UX'M`N0`,%!(?($!Q8?O_5"$`@%+@`Q>J[_?_E^#Z_S7A`Q>J````
ML`#<+I$\_O^7X`,7JCCX_Y?U`P"JLO__%Q`>@M+]>T"I\U-!J?5;0JGW8T.I
M^6M$J?LK0/G_8S"+P`-?UN$#`*H"`$`Y8@``->`#`:K``U_6``0`D5^\`'$A
M$(":^?__%Z`'`+3]>[ZI_0,`D?,+`/GS`P"J`0!`.<$``#4```"P`)0MD?,+
M0/G]>\*H&/C_%Y_X_Y<"!`#18@("BW\"`NMB`P!40`!`.1^\`'%@`@!4X`,"
MJ@'T7S@_O`!Q(0(`5$($`-%_`@+K@@``5$``0#D?O`!Q8/__5$(`$\M`"`"1
M'P1`\4@#`%1"!`"17P1`\>D!`%0`?2#40@0`T>C__Q?B`P"J?P(`ZT/]_U1_
M`@+K@?W_5&`"0#D?O`!Q`/O_5````+``&"^1U___%Z,``/!C0`.1X0,3JN`#
M`ZH8^/^7\PM`^?U[PJC``U_6``"`TOS__Q<```"P`)0MD<S__Q?]>[FI_0,`
MD?-3`:FS``#0%```L&#F1_GU6P*I%@``L/<;`/D7``"P%0``L+4^,)$!`$#Y
MX3<`^0$`@-(```"P`.`LD0`H`)$"#$"IX@\$J0(,0:GB#P6I`$!`>>##`'D`
M``"P`"`OD:?]_Y<```"P`$0OD:3]_Y<```"P`&0OD:']_Y<```"P`(@OD9[]
M_Y?`IB^1G/W_EP```+``Y"^1F?W_E^"Z+I&7_?^7@!8PD97]_Y?@`Q6JD_W_
MEP```+``9#"1D/W_EP```+``W"Z1C?W_EP```+``C#"1>/W_EX```+3A`P"J
MX`,5JJK]_Y<```"P`-`PD7']_Y>@``"TX0,`J@```+``&#&1HOW_EP```+``
M1#&1:?W_E\`!`+3A`P"JX+HND9O]_Y<!``"PP*8OD2'T,9&7_?^7<^9'^>$W
M0/E@`D#Y(```RD`"`+0;^/^7````L`"$,9%8_?^7@```M.$#`*J`%C"1[___
M%P$``+#U`P&10@&`TB'(,9'@1P&1<O?_ER#]_S6A;@"1]O__%_-30:GU6T*I
M]QM`^?U[QZC``U_6_7N^J?T#`)'S"P#YLP``\&`*0+D?!``Q00$`5````+``
M%#"1//W_ET`!`+0``$`Y``$`-!_``''@!Y\:8`H`N6`*0+GS"T#Y_7O"J,`#
M7]8``(!2^O__%_U[OZG]`P"1\??_EWSW_Y>```"T``!`^?U[P:C``U_6``"`
MTOW__Q?]>[VI_0,`D?5;`JD5``"PMOXQD?-3`:GS`P"JX`,6JAW]_Y>```"T
M`0!`.?0#`*KA```UX0,3JJ#^,9'S4T&I]5M"J?U[PZA)_?\7X0,3JDWW_Y>`
M`@"UX`,3JLKW_Y?U`P"JX`,4JL?W_Y>@`@"+``@`D23W_Y?D`Q2J]0,`J@,`
M`+#B`Q.J8Q`OD0$``+`AB#*1K/?_E^$#%:K@`Q:JY___%_-30:GU6T*I_7O#
MJ,`#7]80-I#2_V,PRP("D-+A8R*+_7L`J?T#`)'Y:P2IN0``T!H``+#S4P&I
M]`,`JB#G1_GU6P*I]V,#J?MS!:GH,P#]`@!`^2+,`/D"`(#2H```\``@`)$"
MC$"IX@\(J0(,0JGB#PNI`@Q#J>(/#*D"#$2IX@\-J0(,1:GBCPFI`0Q`^>%+
M`/D`,$#YX%<`^4"[+I'4_/^7(`(`M`$`0#GS`P"JP0$`-*K__Y?@`Q.J`??_
ME_P#`*HYYT?Y`0*0TN%C(8O@`QRJ(LQ`^2$#0/E!``'*X3H`M(/W_Y>3__^7
M\P,`J@`"`+7U8P*1H`)`^8```+43``"0<SXRD0H``!2Y_/^78```M;4B`)'X
M__\7`0!`.:'__S3G]O^7\P,`JD#__[3@`Q.J:_?_EP#X?],6``"0``0`D=9:
M,I'&]O^7]P,`JO4#`*IB`D`Y(@(`-?7#`I&S`D#YDP$`M.`#$ZJA_/^7\P,`
MJ@`"`+0!`$`YP0$`-)[]_Y>``0`TX`,3JLWV_Y?S`P"J]@,"D1```!3@`Q6J
MX0,6JG,&`)$^]_^7M0H`D>G__Q>U(@"1ZO__%^`#%:J._?^7@```-.`#%:J]
M]O^7\P,`JM8B`)&S``"UU0)`^74``+2@`D`YH/[_->`#$ZH\]_^7]@,`JN`#
M%ZHY]_^7%@`6"]82$!$5``"0UGY`D^`#%JJ3]O^7"`!GGN4#%ZJC&B^1X@,3
MJ@0``)`!``"0A&PRD2&`,I$:]_^7``%FG@$X@%+_]O^7'P0`,8$"`%3X]O^7
M``!`N1]$`'$``@!4H```L(("0/GB.P#Y`,!'^1,`0/GO]O^7!`!`N0,!9I[B
M.T#Y`0``D.`#$ZHAI#*1S/;_EQP`@-*+__\7``%FGO>#`Y'A`Q>J?O;_E_,#
M`"I``0`TH```L`,!9IZ"`D#Y`0``D`#`1_DAD#.1``!`^;SV_Y?P__\7X/-`
MN0`,%!(?$$!Q@?[_5/C[0+D%]_^7'P,`:P'^_U3@\T"Y`"``$A\`!W&!_?]4
MX`,6JE7V_Y?\`P"J````D``H,I$U_/^78`L`M98"0/G@`Q:J[?;_E_@#`*H?
M#`!QC0,`5`!\0),!``"0`!``T2'<-)'``@"+*/;_EZ`"`#4?$P!QP```5!@3
M`%'8PCB+`/-?.!^\`''!`0!4E`9`^90!`+3@`Q2JV/;_EQ\,`/$)`0!4`!``
MT0$``)"``@"+(?`TD17V_Y<?``!QUA*4FLW^_Y>@'P`U`0"`4N`#%JI&]O^7
M^`,`*@`?`#1"`(!2(0*`DO:C!I$`]O^7P@"`TN$#%JK@`Q@JB/;_E^"C1CD@
M!@`UX*=&.1\,`7'!!0!4X*M&.1\$`7%A!0!4X*]&.1\,`7$!!0!4X+-&.1\@
M`7&A!`!4X+=&.1\4`7%!!`!40@"`4B$'@)+@`Q@JY_7_ER(%@-+A`Q:JX`,8
M*F_V_Y<%``"0Y`,6JJ7D-Y$"`6:>`0``D*,:+Y$A!#61X`,<JH[V_Y<``6:>
M>/;_E^$#'*I`NRZ1$_S_E^`#'*JV_O^7#___%Y8"0/D,]O^7X0,`JN`#%JII
M_?^7]@,`JB#T_[6?__\7`@"`4@$`@-+@`Q@JQO7_ER!@A-+[X@"1H.BL\N!S
M`/D@<972__\0J:#YO?+@=P#YP)^;TD`7L_+@>P#YP(Z*TO];`;E`!J+RX'\`
M^0`^G-)`>KCRX(,`^>#B`9'@.P#Y`@"0TN$#%JK@`Q@J.O;_E^0#`*KT`P`J
M'P``<8P(`%3@`Q@J+/;_E^"'0/GA8P21XP^`$O0+0;GV$T&Y`"`#4Y0*P%H"
M!``1U@K`6E_@`'$CR"`X0WQ`DPT1`%0!"(!2(@`"2_/B`)$!`(!20GQ`DV`"
M`XNL]?^7X`,7JC+W_Y?@`Q.J`@>`T@$`@%*F]?^7]E,!N>`#%ZKT5P&Y*O?_
ME_3C!9'@XT"Y%@``D/>#!9'D`Q2J``C`6N!C`;G@ZT"YUEHRD1,`@-(`",!:
MX&<!N>#S0+D`",!:X&L!N>#[0+D`",!:X&\!N>`#0;D`",!:X',!N>)J<SC@
M`Q2JX0,6JG,&`)'D.P#YE`H`D2+V_Y=_4@#QY#M`^>'^_U0%``"0I>0WD?^#
M!CF(__\7X8=`^8!\0),B#``+/P`"ZXD``%3ABT#Y(00`D>&+`/GABT#Y('1`
MB^*#$*G@6T&YH`@`-!0(@%*4`@!+GP`4:V##((N4T)0:'P`6ZY-^0)."``!4
M`0`3B]\"`>O#``!4'P`6ZZD``%3!`A.+'P`!ZT(``%0`?2#4Y#\`^7\B0/&H
M__]4X@,3JN$#%JK[]?^7X%M!N>0_0/F``@`+X%L!N1\``7&!\?]4E``42],"
M$XO@`Q>JV?;_E^$#$ZJ?_@!Q3`(`5()^0)-_`AOKB0``5&`#`HM_`@#KX_S_
M5#\`&^N"``!4(``"BW\#`.M#_/]47R`!\0C\_U3@`QNJW_7_E_1;`;ET__\7
M/P`;ZXD``%3@.T#Y/P``Z^/Z_U0_`!OK,P`!D6(``%1_`Q/K0_K_5`((@-+@
M`QNJE`(!4<_U_Y?<__\7\P,6JMS__Q<!!X!2(@`"2^#B`)$!`(!20GQ`DP``
M`XM___\7`0``D"'T,9$```"0`!0PD4;[_Y<6``"0"O7_EP(!9I[6>C61%```
MD+4:+Y&4YC>1Y`,`*N4#%*KC`Q6J`0``D.`#'*HA0#61KO7_EP$X@%+@`QRJ
MD_7_EQ\$`#&!X_]4C/7_EP``0+D?1`!Q`>/_5/3T_Y<"`6:><P8`$>0#`"KF
M`Q2JY0,3*N,#%:KA`Q:JX`,<JIOU_Y?M__\7$#:0TN@S0/W]>T"I\U-!J?5;
M0JGW8T.I^6M$J?MS1:G_8S"+P`-?UOU[NJG]`P"1\U,!J;,``+!TVD?Y]5L"
MJ?=C`ZGY:P2I^W,%J8`"0+F!]?^7]0,`JH`"0+E^]?^7H>)".0'D`CD```"0
M`*0OD='Z_Y?```"T`0!`.3_$`'%A``!4``1`.4```#0;_?^7=MI'^;0``-#`
M`D"Y;O7_EP$``)!C`8!2(@"`4B&\-9$%]?^7(`0`M7;:1_G``D"Y9?7_EV,`
M@%(B`(!2`0``D"'0-9'\]/^7]0,`J@`*`+5VVD?YP`)`N5OU_Y=C`(!2(@"`
M4@$``)`A[#61\O3_E_4#`*I`#`"T````D`#<+I&I^O^7]P,`JD`*`+3``D"Y
M3?7_EZ$*0/GB`Q>J(0!`^>WT_Y=6```4``A`^1J`@%*9P@*1-0"`4AH$H'(;
M%$#YN`8`42$'0+G``D"Y/P`5:PT!`%0\]?^7`P"`4@)_0)/A`QNJG/3_E_<#
M`*I``0"U@,("D0$$0+DA!`!1/P`8:T'Y_U0V`(!2]0,`JG?:1_D:```4`0!`
M^2`'0/D<V'7X(`Q`N0``&@H?`!!Q`0$`5"`(0/GA`P"JX`,<JGKT_Y>`_?\U
MM08`$=[__Q?``D"Y'?7_E^$"0/E#`(!2`@"`TBGU_Y?T__\7U@8`$1;U_Y?A
M`QNJ0/3_EZ$&0+G@`D"Y/P`6:RS__U2H__\7P`)`N0WU_Y>A"D#Y`@``D$+8
M-9$A`$#YK/3_EZ`*0/D``$#Y``Q`N>#TMS;``D"Y`O7_EZ$*0/DA`$#Y:_3_
MEZ'__Q><^_^7]P,`JL`"0+GW!`"T^?3_EZ$*0/GB`Q>J(0!`^9GT_Y?@`Q>J
MX_3_EW/:1_E@`D"Y\/3_E_4#`*I@`D"Y[?3_ER(`@%(!``"0(?0UD2'T_Y<"
M``"0X0,`JD)(-I'@`Q6JB/3_EV`"0+F3P@*1X?3_EQ_D`CD```"0`+@ND37Z
M_Y=@"@#YP`$`M6`&0/DY_?^78`H`^4`!`+4```"0`&`VD1ST_Y?3]/^7@<("
MD2($0/FA"D#Y0@!`^83__Q>4P@*1`3B`4H`*0/FV]/^7'T0`<4`!`%0!!``1
M/P0`<>D``%2!BD"IXP,`*@```)``Y#:1(0!`^0?T_Y?S4T&I]5M"J?=C0ZGY
M:T2I^W-%J?U[QJC``U_6_7N^J?T#`)'S4P&I\P,`JAS\_Y<2_/^7]`,`JL/\
M_Y?``0`TLP$`M&`"0#E@`0`T`0``D.`#%*HA;#*1//3_EY\"`.NA``!4X`,3
MJO-30:G]>\*HJ?K_%_-30:G]>\*HP`-?UOU[OZG]`P"1_7O!J,`#7]9P97)L
M>'-I+F,`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```"XN`"5S
M+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!
M4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%
M`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)
M5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?
M0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?
M5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#
M3$5!3CT`,0!,1%],24)205)97U!!5$@`4UE35$5-`"4P,G@`<&%R+0`E<R5S
M)7,E<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@
M;W!E<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP
M+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C
M:V5R.CI615)324].`#$N,#0W`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`55-%4@!54T523D%-
M10!414U01$E2`%1-4``O=&UP`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI
M('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I
M;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS
M=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR
M;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-
M4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%
M(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD[
M"G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P
M-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@
M+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C
M;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E
M<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T
M7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D
M<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D
M<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED
M>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E
M="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E
M96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E
M860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@
M(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I
M9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X
M(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@
M,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*
M)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K
M*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68[
M"F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD
M(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]
M("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E
M86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO
M9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.
M0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E
M:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA
M;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I
M92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO
M="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S
M7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%
M55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL
M97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T
M7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@
M("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI
M.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF
M="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]
M"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN
M8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`
M861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U
M<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L
M<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H
M)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@
M)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO
M9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J
M,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R
M(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E
M9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X[
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V
M86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@
M)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U
M8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N
M("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@
M)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE
M9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF
M;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I
M.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE
M;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@
M)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O
M6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@
M(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E
M;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B
M*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R
M("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE
M("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?
M;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@
M)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]
M>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER
M92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<
M5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE
M;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D
M8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P
M<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@
M*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H
M+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M
M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO
M<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D
M*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID
M96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@
M*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D
M=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR
M971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B
M0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN
M8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@
M;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L
M:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E
M;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T
M("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N
M;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D
M,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF
M("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```1L#
M.]@````:````S)/__T`%```0EO__\````#R6__\$`0``=);__Q@!``#<EO__
M/`$```R7__]<`0``\*?__X`!``"LJ/__M`$``/2H___8`0``A*G__P0"``!H
MJ___0`(``+2L__]\`@``/*W__Z0"``!TK?__Q`(``,BM___H`@``^*[__QP#
M``#\KO__,`,``,RP__]\`P``\+#__Y`#``#PL?__S`,``)BS___\`P``\+/_
M_R`$```8M/__0`0``,RT__]X!```(+W__]`$``!PP/__$`4``!``````````
M`7I2``1X'@$;#!\`$````!@````8E?__+``````````0````+````#"5__\X
M`````````"````!`````5)7__V@`````1`X@G02>`T*3`E+>W=,.`````!P`
M``!D````F)7__S``````1`X0G0*>`4?>W0X`````(````(0```"HE?__Y!``
M``!!#J`%1IU4GE,#,03=W@X`````,````*@```!HIO__O`````!!#D"=")X'
M1),&E`65!)8#EP*8`6,*WMW7V-76T]0.`$$+`"````#<````\*;__T@`````
M00XPG0:>!4*3!$[>W=,.`````"@``````0``%*?__Y``````00Y`G0B>!T*5
M!)8#0Y,&E`5=WMW5UM/4#@``.````"P!``!XI___Y`$```!!#F"=#)X+0I,*
ME`E"E0B6!T67!I@%F02:`P)NWMW9VM?8U=;3U`X`````.````&@!```@J?__
M3`$```!!#N`!G1R>&T*3&I091948EA>7%I@5F12:$P)*WMW9VM?8U=;3U`X`
M````)````*0!```PJO__B`````!!#K`!G1:>%4*3%)037M[=T]0.`````!P`
M``#,`0``D*K__S@`````00X0G0*>`4C>W0X`````(````.P!``"HJO__5```
M``!!#B"=!)X#0I,"2M[=TPX`````,````!`"``#8JO__,`$```!"#M!`09V*
M")Z)"$*5A@B6A0A#DX@(E(<(`D/=WM76T]0.`!````!$`@``U*O__P0`````
M````2````%@"``#$J___T`$```!"#O`A09V>!)Z=!$*3G`24FP1#E9H$EID$
M19>8!)B7!)F6!)J5!)N4!`)FW=[;V=K7V-76T]0.`````!````"D`@``2*W_
M_R0`````````.````+@"``!8K?__``$```!"#B"=!)X#0I,"1][=TPX`00X@
MDP*=!)X#;@K>W=,.`$$+0@X`T]W>````+````/0"```<KO__J`$```!!#G"=
M#IX-0I,,E`M$E0J6"4*7"`)@WMW7U=;3U`X`(````"0#``"4K___6`````!!
M#B"=!)X#0I,"4`K>W=,.`$$+'````$@#``#(K___*`````!!#A"=`IX!1@K>
MW0X`00LT````:`,``-"O__^T`````$$.,)T&G@5"E0*6`4.3!)0#3`K>W=76
MT]0.`$$+6=[=U=;3U`X``%0```"@`P``3+#__U0(````0@ZP@P)#G;8@GK4@
M0IFN()JM($.3M""4LR!&E;(@EK$@E[`@F*\@FZP@G*L@!4BJ(`,$`@9(W=[;
MW-G:U]C5UM/4#@`````\````^`,``$BX__]0`P```$$.8)T,G@M"DPJ4"4:5
M")8'EP:8!9D$F@.;`IP!`LK>W=O<V=K7V-76T]0.````+````#@$``!8N___
M9`````!!#B"=!)X#0I,"E`%2"M[=T]0.`$$+0M[=T]0.````*````&@$``"$
MCO__^`$```!!#E"="IX)0I,(E`=#E08"<@K>W=73U`X`00L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````P(0```````,@@`````````0`````````!
M``````````$`````````X0(````````/`````````'($````````#```````
M```(&@````````T`````````*$L````````9`````````'B;`0``````&P``
M```````(`````````!H`````````@)L!```````<``````````@`````````
M]?[_;P`````@`@````````4`````````V`P````````&```````````#````
M````"@````````"0!`````````L`````````&``````````5````````````
M`````````P````````!HG0$```````(`````````T`4````````4````````
M``<`````````%P`````````X%`````````<`````````:!$````````(````
M`````-`"````````"0`````````8`````````!@```````````````````#[
M__]O``````$```@`````^?__;P`````0````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(!H````````@&@```````"`:````````(!H````````@&@```````"`:````
M````(!H````````@&@```````"`:````````(!H````````@&@```````"`:
M````````(!H````````@&@```````"`:````````(!H````````@&@``````
M`"`:````````(!H````````@&@```````"`:````````(!H````````@&@``
M`````"`:````````(!H````````@&@```````"`:````````(!H````````@
M&@```````"`:````````(!H````````@&@```````"`:````````(!H`````
M```@&@```````"`:````````(!H````````@&@```````"`:````````(!H`
M```````@&@```````"`:````````(!H````````@&@```````"`:````````
M(!H````````@&@```````"`:````````(!H````````@&@```````"`:````
M````(!H````````@&@```````"`:````````(!H````````@&@```````"`:
M````````(!H````````@&@```````"`:````````(!H````````@&@``````
M`(B;`0``````(!X`````````````````````````````*$L`````````````
M````````````````"!H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P`````:3@```````&5+````````````
M``````!&3````````#],````````#DX```````!<3````````!9.````````
M````````````3@````````5.```````````````````?3@```````$=#0SH@
M*$%L<&EN92`X+C(N,"D@."XR+C```"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M``````````````````````````````````````````````L````!`````@``
M`````````@`````````"````````&@````````````````````$`````````
M```````````3````]O__;P(`````````(`(````````@`@```````-P`````
M`````P`````````(````````````````````'0````L````"```````````#
M``````````,```````#8"0````````0````#````"``````````8````````
M`"4````#`````@````````#8#````````-@,````````D`0`````````````
M``````$````````````````````M````!`````(`````````:!$```````!H
M$0```````-`"`````````P`````````(`````````!@`````````-P````0`
M``!"`````````#@4````````.!0```````#0!0````````,````1````"```
M```````8`````````$$````!````!@`````````(&@````````@:````````
M$`````````````````````0````````````````````\`````0````8`````
M````(!H````````@&@`````````$```````````````````0`````````!``
M````````1P````$````&`````````"`>````````(!X````````(+0``````
M````````````!````````````````````$T````!````!@`````````H2P``
M`````"A+````````$`````````````````````0```````````````````!3
M`````0````(`````````.$L````````X2P```````!L_````````````````
M```!````````````````````6P````$````"`````````%2*````````5(H`
M``````#<````````````````````!````````````````````&D````!````
M`@`````````PBP```````#"+````````E`0```````````````````@`````
M``````````````!S````#@````,`````````>)L!``````!XFP````````@`
M```````````````````(``````````@`````````?P````\````#````````
M`(";`0``````@)L````````(````````````````````"``````````(````
M`````(L````&`````P````````"(FP$``````(B;````````X`$````````$
M``````````@`````````$`````````"4`````0````,`````````:)T!````
M``!HG0```````)@"```````````````````(``````````@`````````F0``
M``$````#``````````"@`0```````*````````!X````````````````````
M"````````````````````)\````(`````P````````!XH`$``````'B@````
M````6!````````````````````@```````````````````"D`````0```#``
M``````````````````!XH````````!H````````````````````!````````
M``$``````````0````,`````````````````````````DJ````````"M````
<`````````````````0``````````````````````
